@@ -38,6 +38,8 @@
 #include "io.hpp"
 #include "metadata.hpp"
 
+#include "proj.h"
+
 NS_PROJ_START
 
 namespace crs {
@@ -49,6 +51,16 @@ class DerivedCRS;
 class ProjectedCRS;
 } // namespace crs
 
+namespace io {
+class JSONParser;
+} // namespace io
+
+namespace coordinates {
+class CoordinateMetadata;
+using CoordinateMetadataPtr = std::shared_ptr<CoordinateMetadata>;
+using CoordinateMetadataNNPtr = util::nn<CoordinateMetadataPtr>;
+} // namespace coordinates
+
 /** osgeo.proj.operation namespace
 
   \brief Coordinate operations (relationship between any two coordinate
@@ -93,6 +105,45 @@ using CoordinateOperationPtr = std::shared_ptr<CoordinateOperation>;
 /** Non-null shared pointer of CoordinateOperation */
 using CoordinateOperationNNPtr = util::nn<CoordinateOperationPtr>;
 
+// ---------------------------------------------------------------------------
+
+class CoordinateTransformer;
+/** Shared pointer of CoordinateTransformer */
+using CoordinateTransformerPtr = std::unique_ptr<CoordinateTransformer>;
+/** Non-null shared pointer of CoordinateTransformer */
+using CoordinateTransformerNNPtr = util::nn<CoordinateTransformerPtr>;
+
+/** \brief Coordinate transformer.
+ *
+ * Performs coordinate transformation of coordinate tuplies.
+ *
+ * @since 9.3
+ */
+class PROJ_GCC_DLL CoordinateTransformer {
+  public:
+    //! @cond Doxygen_Suppress
+    PROJ_DLL ~CoordinateTransformer();
+    //! @endcond
+
+    PROJ_DLL PJ_COORD transform(PJ_COORD coord);
+
+  protected:
+    PROJ_FRIEND(CoordinateOperation);
+
+    PROJ_INTERNAL CoordinateTransformer();
+
+    PROJ_INTERNAL static CoordinateTransformerNNPtr
+    create(const CoordinateOperationNNPtr &op, PJ_CONTEXT *ctx);
+
+  private:
+    PROJ_OPAQUE_PRIVATE_DATA
+    INLINED_MAKE_UNIQUE
+    CoordinateTransformer &
+    operator=(const CoordinateTransformer &other) = delete;
+};
+
+// ---------------------------------------------------------------------------
+
 class Transformation;
 /** Shared pointer of Transformation */
 using TransformationPtr = std::shared_ptr<Transformation>;
@@ -141,7 +192,8 @@ class PROJ_GCC_DLL CoordinateOperation : public common::ObjectUsage,
     PROJ_DLL const util::optional<common::DataEpoch> &
     targetCoordinateEpoch() const;
 
-    // virtual void transform(...) = 0;  TODO
+    PROJ_DLL CoordinateTransformerNNPtr
+    coordinateTransformer(PJ_CONTEXT *ctx) const;
 
     /** \brief Return the inverse of the coordinate operation.
      * @throw util::UnsupportedOperationException
@@ -178,6 +230,7 @@ class PROJ_GCC_DLL CoordinateOperation : public common::ObjectUsage,
     PROJ_FRIEND(CoordinateOperationFactory);
     PROJ_FRIEND(ConcatenatedOperation);
     PROJ_FRIEND(io::WKTParser);
+    PROJ_FRIEND(io::JSONParser);
     PROJ_INTERNAL void
     setWeakSourceTargetCRS(std::weak_ptr<crs::CRS> sourceCRSIn,
                            std::weak_ptr<crs::CRS> targetCRSIn);
@@ -193,6 +246,11 @@ class PROJ_GCC_DLL CoordinateOperation : public common::ObjectUsage,
         const std::vector<metadata::PositionalAccuracyNNPtr> &accuracies);
     PROJ_INTERNAL void setHasBallparkTransformation(bool b);
 
+    PROJ_INTERNAL void
+    setSourceCoordinateEpoch(const util::optional<common::DataEpoch> &epoch);
+    PROJ_INTERNAL void
+    setTargetCoordinateEpoch(const util::optional<common::DataEpoch> &epoch);
+
     PROJ_INTERNAL void
     setProperties(const util::PropertyMap
                       &properties); // throw(InvalidValueTypeException)
@@ -331,6 +389,7 @@ class PROJ_GCC_DLL GeneralParameterValue : public util::BaseObject,
 
     friend class Conversion;
     friend class SingleOperation;
+    friend class PointMotionOperation;
     PROJ_INTERNAL virtual void _exportToWKT(io::WKTFormatter *formatter,
                                             const MethodMapping *mapping)
         const = 0; // throw(io::FormattingException)
@@ -664,6 +723,14 @@ class PROJ_GCC_DLL SingleOperation : virtual public CoordinateOperation {
                                        const io::DatabaseContextPtr &dbContext,
                                        bool inOtherDirection) const;
 
+    PROJ_INTERNAL static GeneralParameterValueNNPtr
+    createOperationParameterValueFromInterpolationCRS(int methodEPSGCode,
+                                                      int crsEPSGCode);
+
+    PROJ_INTERNAL static void
+    exportToPROJStringChangeVerticalUnit(io::PROJStringFormatter *formatter,
+                                         double convFactor);
+
   private:
     PROJ_OPAQUE_PRIVATE_DATA
     SingleOperation &operator=(const SingleOperation &other) = delete;
@@ -945,6 +1012,11 @@ class PROJ_GCC_DLL Conversion : public SingleOperation {
         const common::Angle &centerLong, const common::Length &falseEasting,
         const common::Length &falseNorthing);
 
+    PROJ_DLL static ConversionNNPtr createTunisiaMiningGrid(
+        const util::PropertyMap &properties, const common::Angle &centerLat,
+        const common::Angle &centerLong, const common::Length &falseEasting,
+        const common::Length &falseNorthing);
+
     PROJ_DLL static ConversionNNPtr
     createAlbersEqualArea(const util::PropertyMap &properties,
                           const common::Angle &latitudeFalseOrigin,
@@ -960,6 +1032,14 @@ class PROJ_GCC_DLL Conversion : public SingleOperation {
         const common::Length &falseEasting,
         const common::Length &falseNorthing);
 
+    PROJ_DLL static ConversionNNPtr createLambertConicConformal_1SP_VariantB(
+        const util::PropertyMap &properties,
+        const common::Angle &latitudeNatOrigin, const common::Scale &scale,
+        const common::Angle &latitudeFalseOrigin,
+        const common::Angle &longitudeFalseOrigin,
+        const common::Length &eastingFalseOrigin,
+        const common::Length &northingFalseOrigin);
+
     PROJ_DLL static ConversionNNPtr
     createLambertConicConformal_2SP(const util::PropertyMap &properties,
                                     const common::Angle &latitudeFalseOrigin,
@@ -1030,12 +1110,12 @@ class PROJ_GCC_DLL Conversion : public SingleOperation {
 
     PROJ_DLL static ConversionNNPtr
     createEquidistantConic(const util::PropertyMap &properties,
-                           const common::Angle &centerLat,
-                           const common::Angle &centerLong,
+                           const common::Angle &latitudeFalseOrigin,
+                           const common::Angle &longitudeFalseOrigin,
                            const common::Angle &latitudeFirstParallel,
                            const common::Angle &latitudeSecondParallel,
-                           const common::Length &falseEasting,
-                           const common::Length &falseNorthing);
+                           const common::Length &eastingFalseOrigin,
+                           const common::Length &northingFalseOrigin);
 
     PROJ_DLL static ConversionNNPtr
     createEckertI(const util::PropertyMap &properties,
@@ -1217,6 +1297,11 @@ class PROJ_GCC_DLL Conversion : public SingleOperation {
         const common::Angle &centerLong, const common::Length &falseEasting,
         const common::Length &falseNorthing);
 
+    PROJ_DLL static ConversionNNPtr createMercatorSpherical(
+        const util::PropertyMap &properties, const common::Angle &centerLat,
+        const common::Angle &centerLong, const common::Length &falseEasting,
+        const common::Length &falseNorthing);
+
     PROJ_DLL static ConversionNNPtr
     createMollweide(const util::PropertyMap &properties,
                     const common::Angle &centerLong,
@@ -1379,15 +1464,15 @@ class PROJ_GCC_DLL Conversion : public SingleOperation {
     PROJ_DLL static ConversionNNPtr
     createGeographic2DOffsets(const util::PropertyMap &properties,
                               const common::Angle &offsetLat,
-                              const common::Angle &offsetLon);
+                              const common::Angle &offsetLong);
 
     PROJ_DLL static ConversionNNPtr createGeographic3DOffsets(
         const util::PropertyMap &properties, const common::Angle &offsetLat,
-        const common::Angle &offsetLon, const common::Length &offsetHeight);
+        const common::Angle &offsetLong, const common::Length &offsetHeight);
 
     PROJ_DLL static ConversionNNPtr createGeographic2DWithHeightOffsets(
         const util::PropertyMap &properties, const common::Angle &offsetLat,
-        const common::Angle &offsetLon, const common::Length &offsetHeight);
+        const common::Angle &offsetLong, const common::Length &offsetHeight);
 
     PROJ_DLL static ConversionNNPtr
     createVerticalOffset(const util::PropertyMap &properties,
@@ -1583,19 +1668,19 @@ class PROJ_GCC_DLL Transformation : public SingleOperation {
     PROJ_DLL static TransformationNNPtr createGeographic2DOffsets(
         const util::PropertyMap &properties, const crs::CRSNNPtr &sourceCRSIn,
         const crs::CRSNNPtr &targetCRSIn, const common::Angle &offsetLat,
-        const common::Angle &offsetLon,
+        const common::Angle &offsetLong,
         const std::vector<metadata::PositionalAccuracyNNPtr> &accuracies);
 
     PROJ_DLL static TransformationNNPtr createGeographic3DOffsets(
         const util::PropertyMap &properties, const crs::CRSNNPtr &sourceCRSIn,
         const crs::CRSNNPtr &targetCRSIn, const common::Angle &offsetLat,
-        const common::Angle &offsetLon, const common::Length &offsetHeight,
+        const common::Angle &offsetLong, const common::Length &offsetHeight,
         const std::vector<metadata::PositionalAccuracyNNPtr> &accuracies);
 
     PROJ_DLL static TransformationNNPtr createGeographic2DWithHeightOffsets(
         const util::PropertyMap &properties, const crs::CRSNNPtr &sourceCRSIn,
         const crs::CRSNNPtr &targetCRSIn, const common::Angle &offsetLat,
-        const common::Angle &offsetLon, const common::Length &offsetHeight,
+        const common::Angle &offsetLong, const common::Length &offsetHeight,
         const std::vector<metadata::PositionalAccuracyNNPtr> &accuracies);
 
     PROJ_DLL static TransformationNNPtr createVerticalOffset(
@@ -1685,8 +1770,61 @@ class PROJ_GCC_DLL PointMotionOperation : public SingleOperation {
     PROJ_DLL ~PointMotionOperation() override;
     //! @endcond
 
+    PROJ_DLL const crs::CRSNNPtr &sourceCRS() PROJ_PURE_DECL;
+
+    PROJ_DLL CoordinateOperationNNPtr inverse() const override;
+
+    PROJ_DLL static PointMotionOperationNNPtr
+    create(const util::PropertyMap &properties, const crs::CRSNNPtr &crsIn,
+           const OperationMethodNNPtr &methodIn,
+           const std::vector<GeneralParameterValueNNPtr> &values,
+           const std::vector<metadata::PositionalAccuracyNNPtr>
+               &accuracies); // throw InvalidOperation
+
+    PROJ_DLL static PointMotionOperationNNPtr
+    create(const util::PropertyMap &propertiesOperation,
+           const crs::CRSNNPtr &crsIn,
+           const util::PropertyMap &propertiesOperationMethod,
+           const std::vector<OperationParameterNNPtr> &parameters,
+           const std::vector<ParameterValueNNPtr> &values,
+           const std::vector<metadata::PositionalAccuracyNNPtr>
+               &accuracies); // throw InvalidOperation
+
+    PROJ_DLL PointMotionOperationNNPtr substitutePROJAlternativeGridNames(
+        io::DatabaseContextNNPtr databaseContext) const;
+
+    PROJ_PRIVATE :
+        //! @cond Doxygen_Suppress
+        PROJ_INTERNAL PointMotionOperationNNPtr
+        shallowClone() const;
+
+    PROJ_INTERNAL PointMotionOperationNNPtr
+    cloneWithEpochs(const common::DataEpoch &sourceEpoch,
+                    const common::DataEpoch &targetEpoch) const;
+
+    PROJ_INTERNAL void _exportToPROJString(io::PROJStringFormatter *formatter)
+        const override; // throw(FormattingException)
+
+    PROJ_INTERNAL void _exportToWKT(io::WKTFormatter *formatter)
+        const override; // throw(io::FormattingException)
+
+    PROJ_INTERNAL void _exportToJSON(io::JSONFormatter *formatter)
+        const override; // throw(FormattingException)
+
+    //! @endcond
+
+  protected:
+    PROJ_INTERNAL PointMotionOperation(
+        const crs::CRSNNPtr &crsIn, const OperationMethodNNPtr &methodIn,
+        const std::vector<GeneralParameterValueNNPtr> &values,
+        const std::vector<metadata::PositionalAccuracyNNPtr> &accuracies);
+    PROJ_INTERNAL PointMotionOperation(const PointMotionOperation &other);
+    INLINED_MAKE_SHARED
+
+    PROJ_INTERNAL CoordinateOperationNNPtr _shallowClone() const override;
+
   private:
-    PointMotionOperation(const PointMotionOperation &) = delete;
+    PointMotionOperation &operator=(const PointMotionOperation &) = delete;
 };
 
 // ---------------------------------------------------------------------------
@@ -1750,7 +1888,8 @@ class PROJ_GCC_DLL ConcatenatedOperation final : public CoordinateOperation {
     PROJ_INTERNAL static void
     fixStepsDirection(const crs::CRSNNPtr &concatOpSourceCRS,
                       const crs::CRSNNPtr &concatOpTargetCRS,
-                      std::vector<CoordinateOperationNNPtr> &operationsInOut);
+                      std::vector<CoordinateOperationNNPtr> &operationsInOut,
+                      const io::DatabaseContextPtr &dbContext);
     //! @endcond
 
   protected:
@@ -1899,12 +2038,28 @@ class PROJ_GCC_DLL CoordinateOperationContext {
     PROJ_DLL const std::vector<std::pair<std::string, std::string>> &
     getIntermediateCRS() const;
 
+    PROJ_DLL void
+    setSourceCoordinateEpoch(const util::optional<common::DataEpoch> &epoch);
+
+    PROJ_DLL const util::optional<common::DataEpoch> &
+    getSourceCoordinateEpoch() const;
+
+    PROJ_DLL void
+    setTargetCoordinateEpoch(const util::optional<common::DataEpoch> &epoch);
+
+    PROJ_DLL const util::optional<common::DataEpoch> &
+    getTargetCoordinateEpoch() const;
+
     PROJ_DLL static CoordinateOperationContextNNPtr
     create(const io::AuthorityFactoryPtr &authorityFactory,
            const metadata::ExtentPtr &extent, double accuracy);
 
+    PROJ_DLL CoordinateOperationContextNNPtr clone() const;
+
   protected:
     PROJ_INTERNAL CoordinateOperationContext();
+    PROJ_INTERNAL
+    CoordinateOperationContext(const CoordinateOperationContext &);
     INLINED_MAKE_UNIQUE
 
   private:
@@ -1942,6 +2097,21 @@ class PROJ_GCC_DLL CoordinateOperationFactory {
                      const crs::CRSNNPtr &targetCRS,
                      const CoordinateOperationContextNNPtr &context) const;
 
+    PROJ_DLL std::vector<CoordinateOperationNNPtr> createOperations(
+        const coordinates::CoordinateMetadataNNPtr &sourceCoordinateMetadata,
+        const crs::CRSNNPtr &targetCRS,
+        const CoordinateOperationContextNNPtr &context) const;
+
+    PROJ_DLL std::vector<CoordinateOperationNNPtr> createOperations(
+        const crs::CRSNNPtr &sourceCRS,
+        const coordinates::CoordinateMetadataNNPtr &targetCoordinateMetadata,
+        const CoordinateOperationContextNNPtr &context) const;
+
+    PROJ_DLL std::vector<CoordinateOperationNNPtr> createOperations(
+        const coordinates::CoordinateMetadataNNPtr &sourceCoordinateMetadata,
+        const coordinates::CoordinateMetadataNNPtr &targetCoordinateMetadata,
+        const CoordinateOperationContextNNPtr &context) const;
+
     PROJ_DLL static CoordinateOperationFactoryNNPtr create();
 
   protected:
