@@ -119,8 +119,10 @@ struct OutputOptions {
         << "                --dump-db-structure [{object_definition} | "
            "{object_reference}] |"
         << std::endl
-        << "                {object_definition} | {object_reference} | "
-           "(-s {srs_def} -t {srs_def})"
+        << "                {object_definition} | {object_reference} |"
+        << std::endl
+        << "                (-s {srs_def} [--s_epoch {epoch}] "
+           "-t {srs_def} [--t_epoch {epoch}])"
         << std::endl;
     std::cerr << std::endl;
     std::cerr << "-o: formats is a comma separated combination of: "
@@ -256,8 +258,8 @@ static ExtentPtr makeBboxFilter(DatabaseContextPtr dbContext,
 
 static BaseObjectNNPtr buildObject(
     DatabaseContextPtr dbContext, const std::string &user_string,
-    const std::string &kind, const std::string &context,
-    bool buildBoundCRSToWGS84,
+    const std::string &epoch, const std::string &kind,
+    const std::string &context, bool buildBoundCRSToWGS84,
     CoordinateOperationContext::IntermediateCRSUse allowUseIntermediateCRS,
     bool promoteTo3D, bool normalizeAxisOrder, bool quiet) {
     BaseObjectPtr obj;
@@ -404,6 +406,11 @@ static BaseObjectNNPtr buildObject(
         auto crs = std::dynamic_pointer_cast<CRS>(obj);
         if (crs) {
             obj = crs->promoteTo3D(std::string(), dbContext).as_nullable();
+        } else {
+            auto cm = std::dynamic_pointer_cast<CoordinateMetadata>(obj);
+            if (cm) {
+                obj = cm->promoteTo3D(std::string(), dbContext).as_nullable();
+            }
         }
     }
 
@@ -414,6 +421,19 @@ static BaseObjectNNPtr buildObject(
         }
     }
 
+    if (!epoch.empty()) {
+        auto crs = std::dynamic_pointer_cast<CRS>(obj);
+        if (crs) {
+            obj = CoordinateMetadata::create(NN_NO_CHECK(crs), std::stod(epoch),
+                                             dbContext)
+                      .as_nullable();
+        } else {
+            std::cerr << context << ": applying epoch to a non-CRS object"
+                      << std::endl;
+            std::exit(1);
+        }
+    }
+
     return NN_NO_CHECK(obj);
 }
 
@@ -447,7 +467,7 @@ static void outputObject(
         std::cout << std::endl;
     }
 
-    auto projStringExportable =
+    const auto projStringExportable =
         nn_dynamic_pointer_cast<IPROJStringExportable>(obj);
     bool alreadyOutputted = false;
     if (projStringExportable) {
@@ -749,7 +769,7 @@ static void outputOperationSummary(
 
     std::cout << ", ";
 
-    auto name = op->nameStr();
+    const auto &name = op->nameStr();
     if (!name.empty()) {
         std::cout << name;
     } else {
@@ -758,7 +778,7 @@ static void outputOperationSummary(
 
     std::cout << ", ";
 
-    auto accuracies = op->coordinateOperationAccuracies();
+    const auto &accuracies = op->coordinateOperationAccuracies();
     if (!accuracies.empty()) {
         std::cout << accuracies[0]->value() << " m";
     } else {
@@ -771,7 +791,7 @@ static void outputOperationSummary(
 
     std::cout << ", ";
 
-    auto domains = op->domains();
+    const auto &domains = op->domains();
     if (!domains.empty() && domains[0]->domainOfValidity() &&
         domains[0]->domainOfValidity()->description().has_value()) {
         std::cout << *(domains[0]->domainOfValidity()->description());
@@ -785,7 +805,7 @@ static void outputOperationSummary(
 
     if (dbContext && getenv("PROJINFO_NO_GRID_CHECK") == nullptr) {
         try {
-            auto setGrids = op->gridsNeeded(dbContext, false);
+            const auto setGrids = op->gridsNeeded(dbContext, false);
             for (const auto &grid : setGrids) {
                 if (!grid.available) {
                     std::cout << ", at least one grid missing";
@@ -821,8 +841,9 @@ static bool is3DCRS(const CRSPtr &crs) {
 // ---------------------------------------------------------------------------
 
 static void outputOperations(
-    DatabaseContextPtr dbContext, const std::string &sourceCRSStr,
-    const std::string &targetCRSStr, const ExtentPtr &bboxFilter,
+    const DatabaseContextPtr &dbContext, const std::string &sourceCRSStr,
+    const std::string &sourceEpoch, const std::string &targetCRSStr,
+    const std::string &targetEpoch, const ExtentPtr &bboxFilter,
     CoordinateOperationContext::SpatialCriterion spatialCriterion,
     bool spatialCriterionExplicitlySpecified,
     CoordinateOperationContext::SourceTargetCRSExtentUse crsExtentUse,
@@ -832,10 +853,10 @@ static void outputOperations(
     const std::string &authority, bool usePROJGridAlternatives,
     bool showSuperseded, bool promoteTo3D, bool normalizeAxisOrder,
     double minimumAccuracy, const OutputOptions &outputOpt, bool summary) {
-    auto sourceObj =
-        buildObject(dbContext, sourceCRSStr, "crs", "source CRS", false,
-                    CoordinateOperationContext::IntermediateCRSUse::NEVER,
-                    promoteTo3D, normalizeAxisOrder, outputOpt.quiet);
+    auto sourceObj = buildObject(
+        dbContext, sourceCRSStr, sourceEpoch, "crs", "source CRS", false,
+        CoordinateOperationContext::IntermediateCRSUse::NEVER, promoteTo3D,
+        normalizeAxisOrder, outputOpt.quiet);
     auto sourceCRS = nn_dynamic_pointer_cast<CRS>(sourceObj);
     CoordinateMetadataPtr sourceCoordinateMetadata;
     if (!sourceCRS) {
@@ -853,10 +874,10 @@ static void outputOperations(
         }
     }
 
-    auto targetObj =
-        buildObject(dbContext, targetCRSStr, "crs", "target CRS", false,
-                    CoordinateOperationContext::IntermediateCRSUse::NEVER,
-                    promoteTo3D, normalizeAxisOrder, outputOpt.quiet);
+    auto targetObj = buildObject(
+        dbContext, targetCRSStr, targetEpoch, "crs", "target CRS", false,
+        CoordinateOperationContext::IntermediateCRSUse::NEVER, promoteTo3D,
+        normalizeAxisOrder, outputOpt.quiet);
     auto targetCRS = nn_dynamic_pointer_cast<CRS>(targetObj);
     CoordinateMetadataPtr targetCoordinateMetadata;
     if (!targetCRS) {
@@ -874,14 +895,6 @@ static void outputOperations(
         }
     }
 
-    if (sourceCoordinateMetadata != nullptr &&
-        targetCoordinateMetadata != nullptr) {
-        std::cerr << "CoordinateMetadata with epoch to CoordinateMetadata "
-                     "with epoch not supported currently."
-                  << std::endl;
-        std::exit(1);
-    }
-
     // TODO: handle promotion of CoordinateMetadata
     if (sourceCRS && targetCRS && dbContext && !promoteTo3D) {
         // Auto-promote source/target CRS if it is specified by its name,
@@ -894,7 +907,7 @@ static void outputOperations(
             auto promoted =
                 sourceCRS->promoteTo3D(std::string(), dbContext).as_nullable();
             if (!promoted->identifiers().empty()) {
-                sourceCRS = promoted;
+                sourceCRS = std::move(promoted);
             }
         } else if (is3DCRS(sourceCRS) && !is3DCRS(targetCRS) &&
                    !targetCRS->identifiers().empty() &&
@@ -903,7 +916,7 @@ static void outputOperations(
             auto promoted =
                 targetCRS->promoteTo3D(std::string(), dbContext).as_nullable();
             if (!promoted->identifiers().empty()) {
-                targetCRS = promoted;
+                targetCRS = std::move(promoted);
             }
         }
     }
@@ -922,6 +935,12 @@ static void outputOperations(
 
         const auto createOperations = [&]() {
             if (sourceCoordinateMetadata) {
+                if (targetCoordinateMetadata) {
+                    return CoordinateOperationFactory::create()
+                        ->createOperations(
+                            NN_NO_CHECK(sourceCoordinateMetadata),
+                            NN_NO_CHECK(targetCoordinateMetadata), ctxt);
+                }
                 return CoordinateOperationFactory::create()->createOperations(
                     NN_NO_CHECK(sourceCoordinateMetadata),
                     NN_NO_CHECK(targetCRS), ctxt);
@@ -1020,7 +1039,9 @@ int main(int argc, char **argv) {
     std::string user_string;
     bool user_string_specified = false;
     std::string sourceCRSStr;
+    std::string sourceEpoch;
     std::string targetCRSStr;
+    std::string targetEpoch;
     bool outputSwitchSpecified = false;
     OutputOptions outputOpt;
     std::string objectKind;
@@ -1057,7 +1078,7 @@ int main(int argc, char **argv) {
     bool listCRSSpecified = false;
 
     for (int i = 1; i < argc; i++) {
-        std::string arg(argv[i]);
+        const std::string arg(argv[i]);
         if (arg == "-o" && i + 1 < argc) {
             outputSwitchSpecified = true;
             i++;
@@ -1193,9 +1214,15 @@ int main(int argc, char **argv) {
         } else if ((arg == "-s" || arg == "--source-crs") && i + 1 < argc) {
             i++;
             sourceCRSStr = argv[i];
+        } else if (arg == "--s_epoch" && i + 1 < argc) {
+            i++;
+            sourceEpoch = argv[i];
         } else if ((arg == "-t" || arg == "--target-crs") && i + 1 < argc) {
             i++;
             targetCRSStr = argv[i];
+        } else if (arg == "--t_epoch" && i + 1 < argc) {
+            i++;
+            targetEpoch = argv[i];
         } else if (arg == "-q" || arg == "--quiet") {
             outputOpt.quiet = true;
         } else if (arg == "--c-ify") {
@@ -1574,10 +1601,10 @@ int main(int argc, char **argv) {
 
     if (!user_string.empty()) {
         try {
-            auto obj(buildObject(dbContext, user_string, objectKind,
-                                 "input string", buildBoundCRSToWGS84,
-                                 allowUseIntermediateCRS, promoteTo3D,
-                                 normalizeAxisOrder, outputOpt.quiet));
+            auto obj(buildObject(
+                dbContext, user_string, std::string(), objectKind,
+                "input string", buildBoundCRSToWGS84, allowUseIntermediateCRS,
+                promoteTo3D, normalizeAxisOrder, outputOpt.quiet));
             if (guessDialect) {
                 auto dialect = WKTParser().guessDialect(user_string);
                 std::cout << "Guessed WKT dialect: ";
@@ -1671,8 +1698,8 @@ int main(int argc, char **argv) {
     } else {
         auto bboxFilter = makeBboxFilter(dbContext, bboxStr, area, true);
         try {
-            outputOperations(dbContext, sourceCRSStr, targetCRSStr, bboxFilter,
-                             spatialCriterion,
+            outputOperations(dbContext, sourceCRSStr, sourceEpoch, targetCRSStr,
+                             targetEpoch, bboxFilter, spatialCriterion,
                              spatialCriterionExplicitlySpecified, crsExtentUse,
                              gridAvailabilityUse, allowUseIntermediateCRS,
                              pivots, authority, usePROJGridAlternatives,
