@@ -40,8 +40,6 @@
  * DEALINGS IN THE SOFTWARE.
  *****************************************************************************/
 
-#define PJ_LIB_
-
 #include "proj_internal.h"
 #include <math.h>
 
@@ -224,7 +222,7 @@ static PJ_LP cart_reverse(PJ_XY xy, PJ *P) {
 }
 
 /*********************************************************************/
-PJ *CONVERSION(cart, 1) {
+PJ *PJ_CONVERSION(cart, 1) {
     /*********************************************************************/
     P->fwd3d = cartesian;
     P->inv3d = geodetic;
