@@ -173,10 +173,10 @@ struct CoordinateSystemAxis::Private {
     std::string abbreviation{};
     const AxisDirection *direction = &(AxisDirection::UNSPECIFIED);
     common::UnitOfMeasure unit{};
+    util::optional<RangeMeaning> rangeMeaning = util::optional<RangeMeaning>();
     util::optional<double> minimumValue{};
     util::optional<double> maximumValue{};
     MeridianPtr meridian{};
-    // TODO rangeMeaning
 };
 //! @endcond
 
@@ -273,6 +273,18 @@ CoordinateSystemAxis::maximumValue() PROJ_PURE_DEFN {
 
 // ---------------------------------------------------------------------------
 
+/** \brief Return the range meaning
+ *
+ * @return the range meaning, or empty.
+ * @since 9.2
+ */
+const util::optional<RangeMeaning> &
+CoordinateSystemAxis::rangeMeaning() PROJ_PURE_DEFN {
+    return d->rangeMeaning;
+}
+
+// ---------------------------------------------------------------------------
+
 /** \brief Return the meridian that the axis follows from the pole, for a
  * coordinate
  * reference system centered on a pole.
@@ -312,6 +324,43 @@ CoordinateSystemAxisNNPtr CoordinateSystemAxis::create(
 
 // ---------------------------------------------------------------------------
 
+/** \brief Instantiate a CoordinateSystemAxis.
+ *
+ * @param properties See \ref general_properties. The name should generally be
+ * defined.
+ * @param abbreviationIn Axis abbreviation (might be empty)
+ * @param directionIn Axis direction
+ * @param unitIn Axis unit
+ * @param minimumValueIn Minimum value along axis
+ * @param maximumValueIn Maximum value along axis
+ * @param rangeMeaningIn Range Meaning
+ * @param meridianIn The meridian that the axis follows from the pole, for a
+ * coordinate
+ * reference system centered on a pole, or nullptr
+ * @return a new CoordinateSystemAxis.
+ * @since 9.2
+ */
+CoordinateSystemAxisNNPtr CoordinateSystemAxis::create(
+    const util::PropertyMap &properties, const std::string &abbreviationIn,
+    const AxisDirection &directionIn, const common::UnitOfMeasure &unitIn,
+    const util::optional<double> &minimumValueIn,
+    const util::optional<double> &maximumValueIn,
+    const util::optional<RangeMeaning> &rangeMeaningIn,
+    const MeridianPtr &meridianIn) {
+    auto csa(CoordinateSystemAxis::nn_make_shared<CoordinateSystemAxis>());
+    csa->setProperties(properties);
+    csa->d->abbreviation = abbreviationIn;
+    csa->d->direction = &directionIn;
+    csa->d->unit = unitIn;
+    csa->d->minimumValue = minimumValueIn;
+    csa->d->maximumValue = maximumValueIn;
+    csa->d->rangeMeaning = rangeMeaningIn;
+    csa->d->meridian = meridianIn;
+    return csa;
+}
+
+// ---------------------------------------------------------------------------
+
 //! @cond Doxygen_Suppress
 void CoordinateSystemAxis::_exportToWKT(
     // cppcheck-suppress passedByValue
@@ -343,7 +392,7 @@ void CoordinateSystemAxis::_exportToWKT(io::WKTFormatter *formatter, int order,
     formatter->startNode(io::WKTConstants::AXIS, !identifiers().empty());
     const std::string &axisName = nameStr();
     const std::string &abbrev = abbreviation();
-    std::string parenthesizedAbbrev = "(" + abbrev + ")";
+    const std::string parenthesizedAbbrev = "(" + abbrev + ")";
     std::string dir = direction().toString();
     std::string axisDesignation;
 
@@ -413,6 +462,24 @@ void CoordinateSystemAxis::_exportToWKT(io::WKTFormatter *formatter, int order,
         unit().type() != common::UnitOfMeasure::Type::NONE) {
         unit()._exportToWKT(formatter);
     }
+    if (isWKT2 && formatter->use2019Keywords()) {
+        if (d->minimumValue.has_value()) {
+            formatter->startNode(io::WKTConstants::AXISMINVALUE, false);
+            formatter->add(*(d->minimumValue));
+            formatter->endNode();
+        }
+        if (d->maximumValue.has_value()) {
+            formatter->startNode(io::WKTConstants::AXISMAXVALUE, false);
+            formatter->add(*(d->maximumValue));
+            formatter->endNode();
+        }
+        if (d->minimumValue.has_value() && d->maximumValue.has_value() &&
+            d->rangeMeaning.has_value()) {
+            formatter->startNode(io::WKTConstants::RANGEMEANING, false);
+            formatter->add(d->rangeMeaning->toString());
+            formatter->endNode();
+        }
+    }
     if (formatter->outputId()) {
         formatID(formatter);
     }
@@ -456,6 +523,22 @@ void CoordinateSystemAxis::_exportToJSON(
         l_unit._exportToJSON(formatter);
     }
 
+    if (d->minimumValue.has_value()) {
+        writer->AddObjKey("minimum_value");
+        writer->Add(*(d->minimumValue));
+    }
+
+    if (d->maximumValue.has_value()) {
+        writer->AddObjKey("maximum_value");
+        writer->Add(*(d->maximumValue));
+    }
+
+    if (d->minimumValue.has_value() && d->maximumValue.has_value() &&
+        d->rangeMeaning.has_value()) {
+        writer->AddObjKey("range_meaning");
+        writer->Add(d->rangeMeaning->toString());
+    }
+
     if (formatter->outputId()) {
         formatID(formatter);
     }
@@ -1205,6 +1288,73 @@ CartesianCS::alterUnit(const common::UnitOfMeasure &unit) const {
 
 // ---------------------------------------------------------------------------
 
+//! @cond Doxygen_Suppress
+AffineCS::~AffineCS() = default;
+//! @endcond
+
+// ---------------------------------------------------------------------------
+
+AffineCS::AffineCS(const std::vector<CoordinateSystemAxisNNPtr> &axisIn)
+    : CoordinateSystem(axisIn) {}
+
+// ---------------------------------------------------------------------------
+
+/** \brief Instantiate a AffineCS.
+ *
+ * @param properties See \ref general_properties.
+ * @param axis1 The first axis.
+ * @param axis2 The second axis.
+ * @return a new AffineCS.
+ */
+AffineCSNNPtr AffineCS::create(const util::PropertyMap &properties,
+                               const CoordinateSystemAxisNNPtr &axis1,
+                               const CoordinateSystemAxisNNPtr &axis2) {
+    std::vector<CoordinateSystemAxisNNPtr> axis{axis1, axis2};
+    auto cs(AffineCS::nn_make_shared<AffineCS>(axis));
+    cs->setProperties(properties);
+    return cs;
+}
+
+// ---------------------------------------------------------------------------
+
+/** \brief Instantiate a AffineCS.
+ *
+ * @param properties See \ref general_properties.
+ * @param axis1 The first axis.
+ * @param axis2 The second axis.
+ * @param axis3 The third axis.
+ * @return a new AffineCS.
+ */
+AffineCSNNPtr AffineCS::create(const util::PropertyMap &properties,
+                               const CoordinateSystemAxisNNPtr &axis1,
+                               const CoordinateSystemAxisNNPtr &axis2,
+                               const CoordinateSystemAxisNNPtr &axis3) {
+    std::vector<CoordinateSystemAxisNNPtr> axis{axis1, axis2, axis3};
+    auto cs(AffineCS::nn_make_shared<AffineCS>(axis));
+    cs->setProperties(properties);
+    return cs;
+}
+
+// ---------------------------------------------------------------------------
+
+//! @cond Doxygen_Suppress
+AffineCSNNPtr AffineCS::alterUnit(const common::UnitOfMeasure &unit) const {
+    const auto &l_axisList = CoordinateSystem::getPrivate()->axisList;
+    if (l_axisList.size() == 2) {
+        return AffineCS::create(util::PropertyMap(),
+                                l_axisList[0]->alterUnit(unit),
+                                l_axisList[1]->alterUnit(unit));
+    } else {
+        assert(l_axisList.size() == 3);
+        return AffineCS::create(
+            util::PropertyMap(), l_axisList[0]->alterUnit(unit),
+            l_axisList[1]->alterUnit(unit), l_axisList[2]->alterUnit(unit));
+    }
+}
+//! @endcond
+
+// ---------------------------------------------------------------------------
+
 //! @cond Doxygen_Suppress
 OrdinalCS::~OrdinalCS() = default;
 //! @endcond
@@ -1273,8 +1423,9 @@ ParametricCS::create(const util::PropertyMap &properties,
 // ---------------------------------------------------------------------------
 
 AxisDirection::AxisDirection(const std::string &nameIn) : CodeList(nameIn) {
-    assert(registry.find(nameIn) == registry.end());
-    registry[nameIn] = this;
+    auto lowerName = tolower(nameIn);
+    assert(registry.find(lowerName) == registry.end());
+    registry[lowerName] = this;
 }
 
 // ---------------------------------------------------------------------------
@@ -1282,7 +1433,30 @@ AxisDirection::AxisDirection(const std::string &nameIn) : CodeList(nameIn) {
 //! @cond Doxygen_Suppress
 const AxisDirection *
 AxisDirection::valueOf(const std::string &nameIn) noexcept {
-    auto iter = registry.find(nameIn);
+    auto iter = registry.find(tolower(nameIn));
+    if (iter == registry.end())
+        return nullptr;
+    return iter->second;
+}
+//! @endcond
+
+// ---------------------------------------------------------------------------
+
+RangeMeaning::RangeMeaning(const std::string &nameIn) : CodeList(nameIn) {
+    auto lowerName = tolower(nameIn);
+    assert(registry.find(lowerName) == registry.end());
+    registry[lowerName] = this;
+}
+
+// ---------------------------------------------------------------------------
+
+RangeMeaning::RangeMeaning() : CodeList(std::string()) {}
+
+// ---------------------------------------------------------------------------
+
+//! @cond Doxygen_Suppress
+const RangeMeaning *RangeMeaning::valueOf(const std::string &nameIn) noexcept {
+    auto iter = registry.find(tolower(nameIn));
     if (iter == registry.end())
         return nullptr;
     return iter->second;
@@ -1294,14 +1468,15 @@ AxisDirection::valueOf(const std::string &nameIn) noexcept {
 
 AxisDirectionWKT1::AxisDirectionWKT1(const std::string &nameIn)
     : CodeList(nameIn) {
-    assert(registry.find(nameIn) == registry.end());
-    registry[nameIn] = this;
+    auto lowerName = tolower(nameIn);
+    assert(registry.find(lowerName) == registry.end());
+    registry[lowerName] = this;
 }
 
 // ---------------------------------------------------------------------------
 
 const AxisDirectionWKT1 *AxisDirectionWKT1::valueOf(const std::string &nameIn) {
-    auto iter = registry.find(nameIn);
+    auto iter = registry.find(tolower(nameIn));
     if (iter == registry.end())
         return nullptr;
     return iter->second;
@@ -1352,7 +1527,7 @@ DateTimeTemporalCS::create(const util::PropertyMap &properties,
 // ---------------------------------------------------------------------------
 
 std::string DateTimeTemporalCS::getWKT2Type(bool use2019Keywords) const {
-    return use2019Keywords ? "TemporalDateTime" : "temporal";
+    return use2019Keywords ? WKT2_2019_TYPE : WKT2_2015_TYPE;
 }
 
 // ---------------------------------------------------------------------------
@@ -1385,7 +1560,7 @@ TemporalCountCS::create(const util::PropertyMap &properties,
 // ---------------------------------------------------------------------------
 
 std::string TemporalCountCS::getWKT2Type(bool use2019Keywords) const {
-    return use2019Keywords ? "TemporalCount" : "temporal";
+    return use2019Keywords ? WKT2_2019_TYPE : WKT2_2015_TYPE;
 }
 
 // ---------------------------------------------------------------------------
@@ -1418,7 +1593,7 @@ TemporalMeasureCS::create(const util::PropertyMap &properties,
 // ---------------------------------------------------------------------------
 
 std::string TemporalMeasureCS::getWKT2Type(bool use2019Keywords) const {
-    return use2019Keywords ? "TemporalMeasure" : "temporal";
+    return use2019Keywords ? WKT2_2019_TYPE : WKT2_2015_TYPE;
 }
 
 } // namespace cs
