@@ -177,7 +177,7 @@ ConcatenatedOperationNNPtr ConcatenatedOperation::create(
         if (interpolationCRSValid) {
             auto subOpInterpCRS = operationsIn[i]->interpolationCRS();
             if (interpolationCRS == nullptr)
-                interpolationCRS = subOpInterpCRS;
+                interpolationCRS = std::move(subOpInterpCRS);
             else if (subOpInterpCRS == nullptr ||
                      !(subOpInterpCRS->isEquivalentTo(
                          interpolationCRS.get(),
@@ -218,7 +218,7 @@ ConcatenatedOperationNNPtr ConcatenatedOperation::create(
                     "Inconsistent chaining of CRS in operations");
             }
         }
-        lastTargetCRS = l_targetCRS;
+        lastTargetCRS = std::move(l_targetCRS);
     }
 
     // When chaining VerticalCRS -> GeographicCRS -> VerticalCRS, use
@@ -265,7 +265,8 @@ ConcatenatedOperationNNPtr ConcatenatedOperation::create(
 void ConcatenatedOperation::fixStepsDirection(
     const crs::CRSNNPtr &concatOpSourceCRS,
     const crs::CRSNNPtr &concatOpTargetCRS,
-    std::vector<CoordinateOperationNNPtr> &operationsInOut) {
+    std::vector<CoordinateOperationNNPtr> &operationsInOut,
+    const io::DatabaseContextPtr & /*dbContext*/) {
 
     // Set of heuristics to assign CRS to steps, and possibly reverse them.
 
@@ -274,10 +275,8 @@ void ConcatenatedOperation::fixStepsDirection(
     };
 
     const auto isGeocentric = [](const crs::CRS *crs) -> bool {
-        auto geodCRS = dynamic_cast<const crs::GeodeticCRS *>(crs);
-        if (geodCRS && geodCRS->coordinateSystem()->axisList().size() == 3)
-            return true;
-        return false;
+        const auto geodCRS = dynamic_cast<const crs::GeodeticCRS *>(crs);
+        return (geodCRS && geodCRS->isGeocentric());
     };
 
     // Apply axis order reversal operation on first operation if needed
@@ -310,6 +309,36 @@ void ConcatenatedOperation::fixStepsDirection(
         }
     }
 
+    // If the first operation is a transformation whose target CRS matches the
+    // source CRS of the concatenated operation, then reverse it.
+    if (operationsInOut.size() >= 2) {
+        auto &op = operationsInOut.front();
+        auto l_sourceCRS = op->sourceCRS();
+        auto l_targetCRS = op->targetCRS();
+        if (l_sourceCRS && l_targetCRS &&
+            !areCRSMoreOrLessEquivalent(l_sourceCRS.get(),
+                                        concatOpSourceCRS.get()) &&
+            areCRSMoreOrLessEquivalent(l_targetCRS.get(),
+                                       concatOpSourceCRS.get())) {
+            op = op->inverse();
+        }
+    }
+
+    // If the last operation is a transformation whose source CRS matches the
+    // target CRS of the concatenated operation, then reverse it.
+    if (operationsInOut.size() >= 2) {
+        auto &op = operationsInOut.back();
+        auto l_sourceCRS = op->sourceCRS();
+        auto l_targetCRS = op->targetCRS();
+        if (l_sourceCRS && l_targetCRS &&
+            !areCRSMoreOrLessEquivalent(l_targetCRS.get(),
+                                        concatOpTargetCRS.get()) &&
+            areCRSMoreOrLessEquivalent(l_sourceCRS.get(),
+                                       concatOpTargetCRS.get())) {
+            op = op->inverse();
+        }
+    }
+
     const auto extractDerivedCRS =
         [](const crs::CRS *crs) -> const crs::DerivedCRS * {
         auto derivedCRS = dynamic_cast<const crs::DerivedCRS *>(crs);
@@ -374,7 +403,7 @@ void ConcatenatedOperation::fixStepsDirection(
             auto derivedCRS = extractDerivedCRS(concatOpTargetCRS.get());
             if (derivedCRS) {
                 if (i >= 1) {
-                    // use the sourceCRS of the previous operation as our source
+                    // use the targetCRS of the previous operation as our source
                     // CRS
                     l_sourceCRS = operationsInOut[i - 1]->targetCRS();
                     // except if it looks like the previous operation should
@@ -386,7 +415,9 @@ void ConcatenatedOperation::fixStepsDirection(
                         areCRSMoreOrLessEquivalent(
                             operationsInOut[i - 1]->sourceCRS().get(),
                             derivedCRS->baseCRS().get())) {
-                        l_targetCRS = operationsInOut[i - 1]->sourceCRS();
+                        l_sourceCRS = operationsInOut[i - 1]->sourceCRS();
+                        operationsInOut[i - 1] =
+                            operationsInOut[i - 1]->inverse();
                     }
                 }
                 if (!l_sourceCRS) {
@@ -499,6 +530,47 @@ void ConcatenatedOperation::fixStepsDirection(
                 auto newOp(Conversion::createGeographicGeocentric(
                     NN_NO_CHECK(prevOpTarget), NN_NO_CHECK(l_targetCRS)));
                 operationsInOut.insert(operationsInOut.begin() + i, newOp);
+                // Particular case for https://github.com/OSGeo/PROJ/issues/3819
+                // where the antepenultimate transformation goes to A
+                // (geographic 3D) // and the last transformation is a NADCON 3D
+                // but between A (geographic 2D) to B (geographic 2D), and the
+                // concatenated transformation target CRS is B (geographic 3D)
+                // This is due to an oddity of the EPSG database that registers
+                // the NADCON 3D transformation between the 2D geographic CRS
+                // and not the 3D ones.
+            } else if (i + 1 == operationsInOut.size() &&
+                       l_sourceCRS->nameStr() == prevOpTarget->nameStr() &&
+                       l_targetCRS->nameStr() == concatOpTargetCRS->nameStr() &&
+                       isGeographic(l_targetCRS.get()) &&
+                       isGeographic(concatOpTargetCRS.get()) &&
+                       isGeographic(l_sourceCRS.get()) &&
+                       isGeographic(prevOpTarget.get()) &&
+                       dynamic_cast<const crs::GeographicCRS *>(
+                           prevOpTarget.get())
+                               ->coordinateSystem()
+                               ->axisList()
+                               .size() == 3 &&
+                       dynamic_cast<const crs::GeographicCRS *>(
+                           l_sourceCRS.get())
+                               ->coordinateSystem()
+                               ->axisList()
+                               .size() == 2 &&
+                       dynamic_cast<const crs::GeographicCRS *>(
+                           l_targetCRS.get())
+                               ->coordinateSystem()
+                               ->axisList()
+                               .size() == 2) {
+                const auto transf =
+                    dynamic_cast<const Transformation *>(op.get());
+                if (transf &&
+                    (transf->method()->getEPSGCode() ==
+                         EPSG_CODE_METHOD_NADCON5_3D ||
+                     transf->parameterValue(
+                         PROJ_WKT2_PARAMETER_LATITUDE_LONGITUDE_ELLIPOISDAL_HEIGHT_DIFFERENCE_FILE,
+                         0))) {
+                    op->setCRSs(NN_NO_CHECK(prevOpTarget), concatOpTargetCRS,
+                                nullptr);
+                }
             }
         }
     }
@@ -664,6 +736,8 @@ CoordinateOperationNNPtr ConcatenatedOperation::inverse() const {
         create(properties, inversedOperations, coordinateOperationAccuracies());
     op->d->computedName_ = d->computedName_;
     op->setHasBallparkTransformation(hasBallparkTransformation());
+    op->setSourceCoordinateEpoch(targetCoordinateEpoch());
+    op->setTargetCoordinateEpoch(sourceCoordinateEpoch());
     return op;
 }
 
@@ -740,7 +814,7 @@ void ConcatenatedOperation::_exportToJSON(
                                                     !identifiers().empty()));
 
     writer->AddObjKey("name");
-    auto l_name = nameStr();
+    const auto &l_name = nameStr();
     if (l_name.empty()) {
         writer->Add("unnamed");
     } else {
@@ -784,7 +858,7 @@ CoordinateOperationNNPtr ConcatenatedOperation::_shallowClone() const {
     for (const auto &subOp : d->operations_) {
         ops.emplace_back(subOp->shallowClone());
     }
-    op->d->operations_ = ops;
+    op->d->operations_ = std::move(ops);
     op->assignSelf(op);
     op->setCRSs(this, false);
     return util::nn_static_pointer_cast<CoordinateOperation>(op);
@@ -796,9 +870,33 @@ CoordinateOperationNNPtr ConcatenatedOperation::_shallowClone() const {
 void ConcatenatedOperation::_exportToPROJString(
     io::PROJStringFormatter *formatter) const // throw(FormattingException)
 {
+    double sourceYear =
+        sourceCoordinateEpoch().has_value()
+            ? getRoundedEpochInDecimalYear(
+                  sourceCoordinateEpoch()->coordinateEpoch().convertToUnit(
+                      common::UnitOfMeasure::YEAR))
+            : 0;
+    double targetYear =
+        targetCoordinateEpoch().has_value()
+            ? getRoundedEpochInDecimalYear(
+                  targetCoordinateEpoch()->coordinateEpoch().convertToUnit(
+                      common::UnitOfMeasure::YEAR))
+            : 0;
+    if (sourceYear > 0 && targetYear == 0)
+        targetYear = sourceYear;
+    else if (targetYear > 0 && sourceYear == 0)
+        sourceYear = targetYear;
+    if (sourceYear > 0) {
+        formatter->addStep("set");
+        formatter->addParam("v_4", sourceYear);
+    }
     for (const auto &operation : operations()) {
         operation->_exportToPROJString(formatter);
     }
+    if (targetYear > 0) {
+        formatter->addStep("set");
+        formatter->addParam("v_4", targetYear);
+    }
 }
 
 // ---------------------------------------------------------------------------
