@@ -637,6 +637,13 @@ static const MethodMapping projectionMethodMappings[] = {
      // LCC 2SP
      paramsLCC2SP},
 
+    {EPSG_NAME_METHOD_AZIMUTHAL_EQUIDISTANT,
+     EPSG_CODE_METHOD_AZIMUTHAL_EQUIDISTANT, "Azimuthal_Equidistant", "aeqd",
+     nullptr, paramsAEQD},
+
+    // We don't actually implement the Modified variant of Azimuthal Equidistant
+    // but the exact one. The difference between both is neglectable in a few
+    // hundred of kilometers away from the center of projection
     {EPSG_NAME_METHOD_MODIFIED_AZIMUTHAL_EQUIDISTANT,
      EPSG_CODE_METHOD_MODIFIED_AZIMUTHAL_EQUIDISTANT, "Azimuthal_Equidistant",
      "aeqd", nullptr, paramsAEQD},
@@ -753,6 +760,13 @@ static const MethodMapping projectionMethodMappings[] = {
     {EPSG_NAME_METHOD_KROVAK, EPSG_CODE_METHOD_KROVAK, "Krovak", "krovak",
      "axis=swu", krovakParameters},
 
+    {EPSG_NAME_METHOD_KROVAK_MODIFIED_NORTH_ORIENTED,
+     EPSG_CODE_METHOD_KROVAK_MODIFIED_NORTH_ORIENTED, nullptr, "mod_krovak",
+     nullptr, krovakParameters},
+
+    {EPSG_NAME_METHOD_KROVAK_MODIFIED, EPSG_CODE_METHOD_KROVAK_MODIFIED,
+     nullptr, "mod_krovak", "axis=swu", krovakParameters},
+
     {EPSG_NAME_METHOD_LAMBERT_AZIMUTHAL_EQUAL_AREA,
      EPSG_CODE_METHOD_LAMBERT_AZIMUTHAL_EQUAL_AREA,
      "Lambert_Azimuthal_Equal_Area", "laea", nullptr, paramsLaea},
@@ -922,7 +936,7 @@ const MethodMapping *getProjectionMethodMappings(size_t &nElts) {
 #define METHOD_NAME_CODE(method)                                               \
     { EPSG_NAME_METHOD_##method, EPSG_CODE_METHOD_##method }
 
-const struct MethodNameCode methodNameCodes[] = {
+const struct MethodNameCode methodNameCodesList[] = {
     // Projection methods
     METHOD_NAME_CODE(TRANSVERSE_MERCATOR),
     METHOD_NAME_CODE(TRANSVERSE_MERCATOR_SOUTH_ORIENTATED),
@@ -1006,11 +1020,13 @@ const struct MethodNameCode methodNameCodes[] = {
     METHOD_NAME_CODE(NADCON5_3D),
     METHOD_NAME_CODE(VERTCON),
     METHOD_NAME_CODE(GEOCENTRIC_TRANSLATION_BY_GRID_INTERPOLATION_IGN),
+    // PointMotionOperation
+    METHOD_NAME_CODE(POINT_MOTION_BY_GRID_CANADA_NTV2_VEL),
 };
 
 const MethodNameCode *getMethodNameCodes(size_t &nElts) {
-    nElts = sizeof(methodNameCodes) / sizeof(methodNameCodes[0]);
-    return methodNameCodes;
+    nElts = sizeof(methodNameCodesList) / sizeof(methodNameCodesList[0]);
+    return methodNameCodesList;
 }
 
 #define PARAM_NAME_CODE(method)                                                \
@@ -1052,6 +1068,7 @@ const struct ParamNameCode paramNameCodes[] = {
     PARAM_NAME_CODE(LATITUDE_LONGITUDE_DIFFERENCE_FILE),
     PARAM_NAME_CODE(GEOID_CORRECTION_FILENAME),
     PARAM_NAME_CODE(VERTICAL_OFFSET_FILE),
+    PARAM_NAME_CODE(GEOID_MODEL_DIFFERENCE_FILE),
     PARAM_NAME_CODE(LATITUDE_DIFFERENCE_FILE),
     PARAM_NAME_CODE(LONGITUDE_DIFFERENCE_FILE),
     PARAM_NAME_CODE(UNIT_CONVERSION_SCALAR),
@@ -1089,6 +1106,8 @@ const struct ParamNameCode paramNameCodes[] = {
     PARAM_NAME_CODE(INCLINATION_IN_LONGITUDE),
     PARAM_NAME_CODE(EPSG_CODE_FOR_HORIZONTAL_CRS),
     PARAM_NAME_CODE(EPSG_CODE_FOR_INTERPOLATION_CRS),
+    // Parameters of point motion operations
+    PARAM_NAME_CODE(POINT_MOTION_VELOCITY_GRID_FILE),
 };
 
 const ParamNameCode *getParamNameCodes(size_t &nElts) {
@@ -1385,6 +1404,14 @@ static const ParamMapping paramVerticalOffsetFile = {
 static const ParamMapping *const paramsVERTCON[] = {&paramVerticalOffsetFile,
                                                     nullptr};
 
+static const ParamMapping paramPointMotiionVelocityGridFile = {
+    EPSG_NAME_PARAMETER_POINT_MOTION_VELOCITY_GRID_FILE,
+    EPSG_CODE_PARAMETER_POINT_MOTION_VELOCITY_GRID_FILE, nullptr,
+    common::UnitOfMeasure::Type::NONE, nullptr};
+
+static const ParamMapping *const paramsPointMotionOperationByVelocityGrid[] = {
+    &paramPointMotiionVelocityGridFile, nullptr};
+
 static const ParamMapping paramSouthPoleLatGRIB = {
     PROJ_WKT2_NAME_PARAMETER_SOUTH_POLE_LATITUDE_GRIB_CONVENTION, 0, nullptr,
     common::UnitOfMeasure::Type::ANGULAR, nullptr};
@@ -1572,6 +1599,10 @@ static const MethodMapping otherMethodMappings[] = {
      nullptr, paramsVERTCON},
     {EPSG_NAME_METHOD_VERTCON_OLDNAME, EPSG_CODE_METHOD_VERTCON, nullptr,
      nullptr, nullptr, paramsVERTCON},
+
+    {EPSG_NAME_METHOD_POINT_MOTION_BY_GRID_CANADA_NTV2_VEL,
+     EPSG_CODE_METHOD_POINT_MOTION_BY_GRID_CANADA_NTV2_VEL, nullptr, nullptr,
+     nullptr, paramsPointMotionOperationByVelocityGrid},
 };
 
 const MethodMapping *getOtherMethodMappings(size_t &nElts) {
