@@ -1,4 +1,4 @@
-#define PJ_LIB_
+
 
 #include <errno.h>
 #include <math.h>
@@ -27,24 +27,25 @@ J. Paul Goode (1919) STUDIES IN PROJECTIONS: ADAPTING THE
 
 C_NAMESPACE PJ *pj_moll(PJ *);
 
-static const double d20 = 20 * DEG_TO_RAD;
-static const double d30 = 30 * DEG_TO_RAD;
-static const double d40 = 40 * DEG_TO_RAD;
-static const double d60 = 60 * DEG_TO_RAD;
-static const double d80 = 80 * DEG_TO_RAD;
-static const double d100 = 100 * DEG_TO_RAD;
-static const double d140 = 140 * DEG_TO_RAD;
-static const double d160 = 160 * DEG_TO_RAD;
-static const double d180 = 180 * DEG_TO_RAD;
-
-static const double EPSLN =
-    1.e-10; /* allow a little 'slack' on zone edge positions */
-
-namespace { // anonymous namespace
-struct pj_opaque {
+namespace pj_imoll_ns {
+struct pj_imoll_data {
     struct PJconsts *pj[6];
 };
-} // anonymous namespace
+
+constexpr double d20 = 20 * DEG_TO_RAD;
+constexpr double d30 = 30 * DEG_TO_RAD;
+constexpr double d40 = 40 * DEG_TO_RAD;
+constexpr double d60 = 60 * DEG_TO_RAD;
+constexpr double d80 = 80 * DEG_TO_RAD;
+constexpr double d100 = 100 * DEG_TO_RAD;
+constexpr double d140 = 140 * DEG_TO_RAD;
+constexpr double d160 = 160 * DEG_TO_RAD;
+constexpr double d180 = 180 * DEG_TO_RAD;
+
+constexpr double EPSLN =
+    1.e-10; /* allow a little 'slack' on zone edge positions */
+
+} // namespace pj_imoll_ns
 
 /*
 Assign an integer index representing each of the 6
@@ -53,8 +54,10 @@ longitude (lam) ranges.
 */
 
 static PJ_XY imoll_s_forward(PJ_LP lp, PJ *P) { /* Spheroidal, forward */
+    using namespace pj_imoll_ns;
+
     PJ_XY xy;
-    struct pj_opaque *Q = static_cast<struct pj_opaque *>(P->opaque);
+    struct pj_imoll_data *Q = static_cast<struct pj_imoll_data *>(P->opaque);
     int z;
 
     if (lp.phi >= 0) { /* 1|2 */
@@ -79,8 +82,10 @@ static PJ_XY imoll_s_forward(PJ_LP lp, PJ *P) { /* Spheroidal, forward */
 }
 
 static PJ_LP imoll_s_inverse(PJ_XY xy, PJ *P) { /* Spheroidal, inverse */
+    using namespace pj_imoll_ns;
+
     PJ_LP lp = {0.0, 0.0};
-    struct pj_opaque *Q = static_cast<struct pj_opaque *>(P->opaque);
+    struct pj_imoll_data *Q = static_cast<struct pj_imoll_data *>(P->opaque);
     const double y90 = sqrt(2.0); /* lt=90 corresponds to y=sqrt(2) */
 
     int z = 0;
@@ -144,7 +149,9 @@ static PJ_LP imoll_s_inverse(PJ_XY xy, PJ *P) { /* Spheroidal, inverse */
     return lp;
 }
 
-static PJ *destructor(PJ *P, int errlev) {
+static PJ *pj_imoll_destructor(PJ *P, int errlev) {
+    using namespace pj_imoll_ns;
+
     int i;
     if (nullptr == P)
         return nullptr;
@@ -152,7 +159,7 @@ static PJ *destructor(PJ *P, int errlev) {
     if (nullptr == P->opaque)
         return pj_default_destructor(P, errlev);
 
-    struct pj_opaque *Q = static_cast<struct pj_opaque *>(P->opaque);
+    struct pj_imoll_data *Q = static_cast<struct pj_imoll_data *>(P->opaque);
 
     for (i = 0; i < 6; ++i) {
         if (Q->pj[i])
@@ -182,8 +189,9 @@ static PJ *destructor(PJ *P, int errlev) {
     -180    -100      -20         80          180
 */
 
-static bool setup_zone(PJ *P, struct pj_opaque *Q, int n, PJ *(*proj_ptr)(PJ *),
-                       double x_0, double y_0, double lon_0) {
+static bool setup_zone(PJ *P, struct pj_imoll_ns::pj_imoll_data *Q, int n,
+                       PJ *(*proj_ptr)(PJ *), double x_0, double y_0,
+                       double lon_0) {
     if (!(Q->pj[n - 1] = proj_ptr(nullptr)))
         return false;
     if (!(Q->pj[n - 1] = proj_ptr(Q->pj[n - 1])))
@@ -195,8 +203,9 @@ static bool setup_zone(PJ *P, struct pj_opaque *Q, int n, PJ *(*proj_ptr)(PJ *),
     return true;
 }
 
-static double compute_zone_offset(struct pj_opaque *Q, int zone1, int zone2,
-                                  double lam, double phi1, double phi2) {
+static double compute_zone_offset(struct pj_imoll_ns::pj_imoll_data *Q,
+                                  int zone1, int zone2, double lam, double phi1,
+                                  double phi2) {
     PJ_LP lp1, lp2;
     PJ_XY xy1, xy2;
 
@@ -209,9 +218,11 @@ static double compute_zone_offset(struct pj_opaque *Q, int zone1, int zone2,
     return (xy2.x + Q->pj[zone2 - 1]->x0) - (xy1.x + Q->pj[zone1 - 1]->x0);
 }
 
-PJ *PROJECTION(imoll) {
-    struct pj_opaque *Q =
-        static_cast<struct pj_opaque *>(calloc(1, sizeof(struct pj_opaque)));
+PJ *PJ_PROJECTION(imoll) {
+    using namespace pj_imoll_ns;
+
+    struct pj_imoll_data *Q = static_cast<struct pj_imoll_data *>(
+        calloc(1, sizeof(struct pj_imoll_data)));
     if (nullptr == Q)
         return pj_default_destructor(P, PROJ_ERR_OTHER /*ENOMEM*/);
     P->opaque = Q;
@@ -223,7 +234,7 @@ PJ *PROJECTION(imoll) {
         !setup_zone(P, Q, 4, pj_moll, -d60, 0, -d60) ||
         !setup_zone(P, Q, 5, pj_moll, d20, 0, d20) ||
         !setup_zone(P, Q, 6, pj_moll, d140, 0, d140)) {
-        return destructor(P, PROJ_ERR_OTHER /*ENOMEM*/);
+        return pj_imoll_destructor(P, PROJ_ERR_OTHER /*ENOMEM*/);
     }
 
     /* Adjust zones */
@@ -249,7 +260,7 @@ PJ *PROJECTION(imoll) {
 
     P->inv = imoll_s_inverse;
     P->fwd = imoll_s_forward;
-    P->destructor = destructor;
+    P->destructor = pj_imoll_destructor;
     P->es = 0.;
 
     return P;
