@@ -1,4 +1,4 @@
-#define PJ_LIB_
+
 
 #include <errno.h>
 #include <math.h>
@@ -29,25 +29,26 @@ J. Paul Goode (1919) STUDIES IN PROJECTIONS: ADAPTING THE
 
 C_NAMESPACE PJ *pj_moll(PJ *);
 
-/* SIMPLIFY THIS */
-static const double d10 = 10 * DEG_TO_RAD;
-static const double d20 = 20 * DEG_TO_RAD;
-static const double d60 = 60 * DEG_TO_RAD;
-static const double d90 = 90 * DEG_TO_RAD;
-static const double d110 = 110 * DEG_TO_RAD;
-static const double d130 = 130 * DEG_TO_RAD;
-static const double d140 = 140 * DEG_TO_RAD;
-static const double d150 = 150 * DEG_TO_RAD;
-static const double d180 = 180 * DEG_TO_RAD;
-
-static const double EPSLN =
-    1.e-10; /* allow a little 'slack' on zone edge positions */
-
-namespace { // anonymous namespace
-struct pj_opaque {
+namespace pj_imoll_o_ns {
+struct pj_imoll_o_data {
     struct PJconsts *pj[6];
 };
-} // anonymous namespace
+
+/* SIMPLIFY THIS */
+constexpr double d10 = 10 * DEG_TO_RAD;
+constexpr double d20 = 20 * DEG_TO_RAD;
+constexpr double d60 = 60 * DEG_TO_RAD;
+constexpr double d90 = 90 * DEG_TO_RAD;
+constexpr double d110 = 110 * DEG_TO_RAD;
+constexpr double d130 = 130 * DEG_TO_RAD;
+constexpr double d140 = 140 * DEG_TO_RAD;
+constexpr double d150 = 150 * DEG_TO_RAD;
+constexpr double d180 = 180 * DEG_TO_RAD;
+
+constexpr double EPSLN =
+    1.e-10; /* allow a little 'slack' on zone edge positions */
+
+} // namespace pj_imoll_o_ns
 
 /*
 Assign an integer index representing each of the 6
@@ -56,8 +57,11 @@ longitude (lam) ranges.
 */
 
 static PJ_XY imoll_o_s_forward(PJ_LP lp, PJ *P) { /* Spheroidal, forward */
+    using namespace pj_imoll_o_ns;
+
     PJ_XY xy;
-    struct pj_opaque *Q = static_cast<struct pj_opaque *>(P->opaque);
+    struct pj_imoll_o_data *Q =
+        static_cast<struct pj_imoll_o_data *>(P->opaque);
     int z;
 
     if (lp.phi >= 0) { /* 1|2|3 */
@@ -85,8 +89,11 @@ static PJ_XY imoll_o_s_forward(PJ_LP lp, PJ *P) { /* Spheroidal, forward */
 }
 
 static PJ_LP imoll_o_s_inverse(PJ_XY xy, PJ *P) { /* Spheroidal, inverse */
+    using namespace pj_imoll_o_ns;
+
     PJ_LP lp = {0.0, 0.0};
-    struct pj_opaque *Q = static_cast<struct pj_opaque *>(P->opaque);
+    struct pj_imoll_o_data *Q =
+        static_cast<struct pj_imoll_o_data *>(P->opaque);
     const double y90 = sqrt(2.0); /* lt=90 corresponds to y=sqrt(2) */
 
     int z = 0;
@@ -153,7 +160,9 @@ static PJ_LP imoll_o_s_inverse(PJ_XY xy, PJ *P) { /* Spheroidal, inverse */
     return lp;
 }
 
-static PJ *destructor(PJ *P, int errlev) {
+static PJ *pj_imoll_o_destructor(PJ *P, int errlev) {
+    using namespace pj_imoll_o_ns;
+
     int i;
     if (nullptr == P)
         return nullptr;
@@ -161,7 +170,8 @@ static PJ *destructor(PJ *P, int errlev) {
     if (nullptr == P->opaque)
         return pj_default_destructor(P, errlev);
 
-    struct pj_opaque *Q = static_cast<struct pj_opaque *>(P->opaque);
+    struct pj_imoll_o_data *Q =
+        static_cast<struct pj_imoll_o_data *>(P->opaque);
 
     for (i = 0; i < 6; ++i) {
         if (Q->pj[i])
@@ -191,8 +201,10 @@ static PJ *destructor(PJ *P, int errlev) {
     -180          -60               90        180
 */
 
-static bool setup_zone(PJ *P, struct pj_opaque *Q, int n, PJ *(*proj_ptr)(PJ *),
-                       double x_0, double y_0, double lon_0) {
+static bool pj_imoll_o_setup_zone(PJ *P,
+                                  struct pj_imoll_o_ns::pj_imoll_o_data *Q,
+                                  int n, PJ *(*proj_ptr)(PJ *), double x_0,
+                                  double y_0, double lon_0) {
     if (!(Q->pj[n - 1] = proj_ptr(nullptr)))
         return false;
     if (!(Q->pj[n - 1] = proj_ptr(Q->pj[n - 1])))
@@ -204,8 +216,10 @@ static bool setup_zone(PJ *P, struct pj_opaque *Q, int n, PJ *(*proj_ptr)(PJ *),
     return true;
 }
 
-static double compute_zone_offset(struct pj_opaque *Q, int zone1, int zone2,
-                                  double lam, double phi1, double phi2) {
+static double
+pj_imoll_o_compute_zone_offset(struct pj_imoll_o_ns::pj_imoll_o_data *Q,
+                               int zone1, int zone2, double lam, double phi1,
+                               double phi2) {
     PJ_LP lp1, lp2;
     PJ_XY xy1, xy2;
 
@@ -218,46 +232,50 @@ static double compute_zone_offset(struct pj_opaque *Q, int zone1, int zone2,
     return (xy2.x + Q->pj[zone2 - 1]->x0) - (xy1.x + Q->pj[zone1 - 1]->x0);
 }
 
-PJ *PROJECTION(imoll_o) {
-    struct pj_opaque *Q =
-        static_cast<struct pj_opaque *>(calloc(1, sizeof(struct pj_opaque)));
+PJ *PJ_PROJECTION(imoll_o) {
+    using namespace pj_imoll_o_ns;
+
+    struct pj_imoll_o_data *Q = static_cast<struct pj_imoll_o_data *>(
+        calloc(1, sizeof(struct pj_imoll_o_data)));
     if (nullptr == Q)
         return pj_default_destructor(P, PROJ_ERR_OTHER /*ENOMEM*/);
     P->opaque = Q;
 
     /* Setup zones */
-    if (!setup_zone(P, Q, 1, pj_moll, -d140, 0, -d140) ||
-        !setup_zone(P, Q, 2, pj_moll, -d10, 0, -d10) ||
-        !setup_zone(P, Q, 3, pj_moll, d130, 0, d130) ||
-        !setup_zone(P, Q, 4, pj_moll, -d110, 0, -d110) ||
-        !setup_zone(P, Q, 5, pj_moll, d20, 0, d20) ||
-        !setup_zone(P, Q, 6, pj_moll, d150, 0, d150)) {
-        return destructor(P, PROJ_ERR_OTHER /*ENOMEM*/);
+    if (!pj_imoll_o_setup_zone(P, Q, 1, pj_moll, -d140, 0, -d140) ||
+        !pj_imoll_o_setup_zone(P, Q, 2, pj_moll, -d10, 0, -d10) ||
+        !pj_imoll_o_setup_zone(P, Q, 3, pj_moll, d130, 0, d130) ||
+        !pj_imoll_o_setup_zone(P, Q, 4, pj_moll, -d110, 0, -d110) ||
+        !pj_imoll_o_setup_zone(P, Q, 5, pj_moll, d20, 0, d20) ||
+        !pj_imoll_o_setup_zone(P, Q, 6, pj_moll, d150, 0, d150)) {
+        return pj_imoll_o_destructor(P, PROJ_ERR_OTHER /*ENOMEM*/);
     }
 
     /* Adjust zones */
 
     /* Match 2 (center) to 1 (west) */
     Q->pj[1]->x0 +=
-        compute_zone_offset(Q, 2, 1, -d90, 0.0 + EPSLN, 0.0 + EPSLN);
+        pj_imoll_o_compute_zone_offset(Q, 2, 1, -d90, 0.0 + EPSLN, 0.0 + EPSLN);
 
     /* Match 3 (east) to 2 (center) */
-    Q->pj[2]->x0 += compute_zone_offset(Q, 3, 2, d60, 0.0 + EPSLN, 0.0 + EPSLN);
+    Q->pj[2]->x0 +=
+        pj_imoll_o_compute_zone_offset(Q, 3, 2, d60, 0.0 + EPSLN, 0.0 + EPSLN);
 
     /* Match 4 (south) to 1 (north) */
-    Q->pj[3]->x0 +=
-        compute_zone_offset(Q, 4, 1, -d180, 0.0 - EPSLN, 0.0 + EPSLN);
+    Q->pj[3]->x0 += pj_imoll_o_compute_zone_offset(Q, 4, 1, -d180, 0.0 - EPSLN,
+                                                   0.0 + EPSLN);
 
     /* Match 5 (south) to 2 (north) */
     Q->pj[4]->x0 +=
-        compute_zone_offset(Q, 5, 2, -d60, 0.0 - EPSLN, 0.0 + EPSLN);
+        pj_imoll_o_compute_zone_offset(Q, 5, 2, -d60, 0.0 - EPSLN, 0.0 + EPSLN);
 
     /* Match 6 (south) to 3 (north) */
-    Q->pj[5]->x0 += compute_zone_offset(Q, 6, 3, d90, 0.0 - EPSLN, 0.0 + EPSLN);
+    Q->pj[5]->x0 +=
+        pj_imoll_o_compute_zone_offset(Q, 6, 3, d90, 0.0 - EPSLN, 0.0 + EPSLN);
 
     P->inv = imoll_o_s_inverse;
     P->fwd = imoll_o_s_forward;
-    P->destructor = destructor;
+    P->destructor = pj_imoll_o_destructor;
     P->es = 0.;
 
     return P;
