@@ -997,10 +997,10 @@ bool Evaluator<Grid, GridSet, EvaluatorIface>::forward(
             double dx11 = 0;
             double dy11 = 0;
             if (compEx->displacementType == DisplacementType::HORIZONTAL) {
-                if (!grid->getLonLatOffset(ix0, iy0, dx00, dy00) ||
-                    !grid->getLonLatOffset(ix1, iy0, dx10, dy10) ||
-                    !grid->getLonLatOffset(ix0, iy1, dx01, dy01) ||
-                    !grid->getLonLatOffset(ix1, iy1, dx11, dy11)) {
+                if (!grid->getLongLatOffset(ix0, iy0, dx00, dy00) ||
+                    !grid->getLongLatOffset(ix1, iy0, dx10, dy10) ||
+                    !grid->getLongLatOffset(ix0, iy1, dx01, dy01) ||
+                    !grid->getLongLatOffset(ix1, iy1, dx11, dy11)) {
                     return false;
                 }
             } else /* if (compEx->displacementType == DisplacementType::THREE_D)
@@ -1010,10 +1010,10 @@ bool Evaluator<Grid, GridSet, EvaluatorIface>::forward(
                 double dz01 = 0;
                 double dz10 = 0;
                 double dz11 = 0;
-                if (!grid->getLonLatZOffset(ix0, iy0, dx00, dy00, dz00) ||
-                    !grid->getLonLatZOffset(ix1, iy0, dx10, dy10, dz10) ||
-                    !grid->getLonLatZOffset(ix0, iy1, dx01, dy01, dz01) ||
-                    !grid->getLonLatZOffset(ix1, iy1, dx11, dy11, dz11)) {
+                if (!grid->getLongLatZOffset(ix0, iy0, dx00, dy00, dz00) ||
+                    !grid->getLongLatZOffset(ix1, iy0, dx10, dy10, dz10) ||
+                    !grid->getLongLatZOffset(ix0, iy1, dx01, dy01, dz01) ||
+                    !grid->getLongLatZOffset(ix1, iy1, dx11, dy11, dz11)) {
                     return false;
                 }
                 const double dzInterp =
